Skip to contents

Get Binance Futures account summary

Usage

futures_get_account_summary(
  acc = NULL,
  json_list = FALSE,
  config = config_futures()
)

get_fapi_account_summary(acc = NULL, config = binxr_config_futures())

Arguments

acc

Optional account payload from futures_get_account(). If NULL, account data is fetched.

json_list

If TRUE, return the parsed list instead of a data.table.

config

A futures configuration created by config_futures().

Value

A one-row data.table by default, or a parsed list when json_list = TRUE.