Skip to contents

Get Binance Futures algo order history

Usage

futures_get_algo_orders(
  symbol,
  startTime = NULL,
  endTime = NULL,
  limit = 500,
  json_list = FALSE,
  config = config_futures()
)

Arguments

symbol

Trading pair symbol.

startTime

Optional start time in milliseconds since Unix epoch.

endTime

Optional end time in milliseconds since Unix epoch.

limit

Maximum number of rows to return. Must not exceed 1000.

json_list

If TRUE, return the parsed list instead of a data.table.

config

A futures configuration created by config_futures().

Value

A data.table by default, or a parsed list when json_list = TRUE.