Skip to contents

Get Binance Futures basis history

Usage

futures_get_basis(
  pair,
  contract_type = c("PERPETUAL", "CURRENT_MONTH", "NEXT_MONTH", "CURRENT_QUARTER",
    "NEXT_QUARTER"),
  period = "5m",
  startTime = NULL,
  endTime = NULL,
  limit = 30,
  json_list = FALSE,
  config = config_futures()
)

Arguments

pair

Futures pair, for example "BTCUSDT".

contract_type

One of "PERPETUAL", "CURRENT_MONTH", "NEXT_MONTH", "CURRENT_QUARTER", or "NEXT_QUARTER".

period

Aggregation period. One of "5m", "15m", "30m", "1h", "2h", "4h", "6h", "12h", or "1d".

startTime

Optional start time in milliseconds since Unix epoch.

endTime

Optional end time in milliseconds since Unix epoch.

limit

Maximum number of rows to return. Must not exceed 500.

json_list

If TRUE, return the parsed list instead of a data.table.

config

A futures configuration created by config_futures().

Value

A data.table by default, or a parsed list when json_list = TRUE.