Skip to contents

Get Binance Futures force orders

Usage

futures_get_force_orders(
  symbol = NULL,
  auto_close_type = NULL,
  startTime = NULL,
  endTime = NULL,
  limit = 50,
  json_list = FALSE,
  config = config_futures()
)

Arguments

symbol

Optional trading pair symbol.

auto_close_type

Optional auto-close type.

startTime

Optional start time in milliseconds since Unix epoch.

endTime

Optional end time in milliseconds since Unix epoch.

limit

Maximum number of rows to return. Must not exceed 100.

json_list

If TRUE, return the parsed list instead of a data.table.

config

A futures configuration created by config_futures().

Value

A data.table by default, or a parsed list when json_list = TRUE.