Skip to contents

Get Binance Futures order modification history

Usage

futures_get_order_amendments(
  symbol,
  order_id = NULL,
  orig_client_order_id = NULL,
  startTime = NULL,
  endTime = NULL,
  limit = 500,
  json_list = FALSE,
  config = config_futures()
)

Arguments

symbol

Trading pair symbol.

order_id

Optional exchange order ID.

orig_client_order_id

Optional client order ID.

startTime

Optional start time in milliseconds since Unix epoch.

endTime

Optional start time in milliseconds since Unix epoch.

limit

Maximum number of rows to return. Must not exceed 1000.

json_list

If TRUE, return the parsed list instead of a data.table.

config

A futures configuration created by config_futures().

Value

A data.table by default, or a parsed list when json_list = TRUE.