Skip to contents

Get Binance Futures order rate limits

Usage

futures_get_order_rate_limit(json_list = FALSE, config = config_futures())

Arguments

json_list

If TRUE, return the parsed list instead of a data.table.

config

A futures configuration created by config_futures().

Value

A data.table by default, or a parsed list when json_list = TRUE.