Skip to contents

Get Binance Options mark prices

Usage

options_get_mark_price(
  symbol = NULL,
  json_list = FALSE,
  config = config_options()
)

Arguments

symbol

Optional option symbol.

json_list

If TRUE, return the parsed list instead of a data.table.

config

An options configuration created by config_options().

Value

A data.table by default, or a parsed list when json_list = TRUE.