Cancel all open Binance Spot orders for a symbol
Source:R/endpoints-spot-trade.R
spot_cancel_all_orders.RdCancel all open Binance Spot orders for a symbol
Usage
spot_cancel_all_orders(symbol, config = config_spot())Arguments
- symbol
Trading pair symbol, for example
"BTCUSDT".- config
A spot configuration created by
config_spot().