Round price and quantity to exchange increments
Source:R/helpers-exchange-info.R
round_price_qty.RdRound price and quantity to exchange increments
Arguments
- exchangeInfo
Exchange info from
futures_get_exchange_info().- symbol
Trading pair symbol, for example
"ETHUSDT".- price
Optional price to round using the symbol tick size.
- quantity
Optional quantity to round using the symbol step size.
- round_dir
Direction:
"down"or"up".